<?php

/**
 * Returns HTML for a fieldset form element and its children.
 *
 * @param $variables
 *   An associative array containing:
 *   - element: An associative array containing the properties of the element.
 *     Properties used: #attributes, #children, #collapsed, #collapsible,
 *     #description, #id, #title, #value.
 *
 * @ingroup themeable
 */
function twbs_fieldset($variables) {
  $element = $variables['element'];
  element_set_attributes($element, array('id'));

  $output = '';

  // Virtual tab or collapsible fieldset under TWBS convert as collapse.
  if (isset($element['#group']) || isset($element['#collapsible'])) {
    $output .= '<div class="panel panel-default">';

    if (!empty($element['#title'])) {
      $options = array(
        'html' => TRUE,
        'fragment' => $element['#id'],
        'attributes' => array(
          'data-toggle' => 'collapse',
        ),
      );
      if (isset($element['#group'])) {
        $options['attributes']['data-parent'] = '#' . $element['#group'];
      }
      $output .= '<div class="panel-heading"><h4 class="panel-title">';
      $output .= l($element['#title'], NULL, $options);
      $output .= '</h4></div>';
    }

    $attributes['id'] = $element['#id'];
    $attributes['class'] = array('panel-collapse', 'collapse');
    if (isset($element['#collapsed']) && !$element['#collapsed']) {
      $attributes['class'][] = 'in';
    }
    $output .= '<div' . drupal_attributes($attributes) . '><div class="panel-body">';
    if (!empty($element['#description'])) {
      $output .= '<p>' . $element['#description'] . '</p>';
    }
    $output .= $element['#children'];
    if (isset($element['#value'])) {
      $output .= $element['#value'];
    }
    $output .= '</div></div>';

    $output .= '</div>';
  }
  // Normal fieldset without TWBS convert.
  else {
    _form_set_class($element, array('form-wrapper'));

    $output .= '<fieldset' . drupal_attributes($element['#attributes']) . '>';
    if (!empty($element['#title'])) {
      // Always wrap fieldset legends in a SPAN for CSS positioning.
      $output .= '<legend><span class="fieldset-legend">' . $element['#title'] . '</span></legend>';
    }
    $output .= '<div class="fieldset-wrapper">';
    if (!empty($element['#description'])) {
      $output .= '<div class="fieldset-description">' . $element['#description'] . '</div>';
    }
    $output .= $element['#children'];
    if (isset($element['#value'])) {
      $output .= $element['#value'];
    }
    $output .= '</div>';
    $output .= "</fieldset>\n";
  }

  return $output;
}
